package de.duehl.math.functionviewer.logic;

import java.awt.Color;

import de.congrace.exp4j.Calculable;
import de.congrace.exp4j.ExpressionBuilder;
import de.congrace.exp4j.UnknownFunctionException;
import de.congrace.exp4j.UnparsableExpressionException;

/**
 * Diese Klasse stellt eine Funktion im FunctionViewers dar.
 *
 * @version 1.01     2014-05-07
 * @author Christian Dühl
 */

public class Function {

    /** Interne Funktion aus exp4j. */
    private final Calculable calculable;

    /** Menschenlesbarer Term. */
    private final String term;

    /** Farbe in der die Funktion angezeigt wird. */
    private Color color;

    /**
     * Konstruktor.
     *
     * @param term
     *            Menschenlesbarer Term.
     * @param color
     *            Farbe in der die Funktion angezeigt wird.
     */
    public Function(String term, Color color) {
        this.term = term;
        this.color = color;
        try {
            calculable = new ExpressionBuilder(term)
                .withVariableNames("x")
                .build();
        }
        catch (UnknownFunctionException | UnparsableExpressionException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * Copy-Konstruktor.
     *
     * @param thatFunction
     *            Funktion, deren Werte zu kopieren sind.
     */
    public Function(Function thatFunction) {
        this(
                thatFunction.getTerm(),
                new Color(thatFunction.getColor().getRed(),
                          thatFunction.getColor().getGreen(),
                          thatFunction.getColor().getBlue()));
    }

    /** Getter für die Farbe, in der die Funktion angezeigt wird. */
    public Color getColor() {
        return color;
    }

    /** Setter für die Farbe, in der die Funktion angezeigt wird. */
    public void setColor(Color color) {
        this.color = color;
    }

    /** Getter für den menschenlesbaren Term. */
    public String getTerm() {
        return term;
    }

    /**
     * Berechnet den Funktionswert an der Stelle x.
     *
     * @param x
     *            Parameter x.
     * @return Funktionswert an der Stelle: f(x)
     */
    public double calculate(double x) {
        calculable.setVariable("x", x);
        return calculable.calculate();
    }

    @Override
    public String toString() {
        return "Function [term=" + term + ", color=" + color + "]";
    }

}
