package de.duehl.math.functionviewer.logic;

import de.duehl.math.functionviewer.ui.FunctionViewerGui;
import de.duehl.swing.logic.Quitter;

import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

import de.duehl.basics.logic.Version;

/**
 * Diese Klasse stellt die Logik des FunctionViewers dar.
 *
 * @version 1.01     2019-07-03
 * @author Christian Dühl
 */

public class FunctionViewerLogic implements Quitter {

    /** Programmversion. */
    private final Version version;

    /** Grafische Oberfläche. */
    private FunctionViewerGui gui;

    /**
     * Konstruktor.
     *
     * @param version
     *            Programmversion.
     */
    public FunctionViewerLogic(Version version) {
        this.version = version;
        gui = new FunctionViewerGui(this);
    }

    /** Zeigt das Programm an. */
    public void start() {
        gui.setVisible(true);
    }

    /** Getter für die Version. */
    public Version getVersion() {
        return version;
    }

    /** Beendet das Programm. */
    @Override
    public void quit() {
        gui.quit();
    }

    /** Fertigt einen Screenshot vom Panel mit den Funktionen an. */
    public void screenshot() {
        String filename = gui.askUserAboutNameForScreenshot();
        if (filename.isEmpty()) {
            return;
        }

        if (!filename.endsWith(".png")) {
            filename = filename + ".png";
        }

        try {
            ImageIO.write(gui.getSnapshot(), "png", new File(filename));
        }
        catch (IOException exception) {
            gui.error("Fehler beim Anfertigen eines Screenshots.", exception);
        }
    }

}
