package de.duehl.math.functionviewer.ui;

import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

/**
 * Diese Klasse stellt den MouseListener für die grafische Oberfläche des FunctionViewers dar.
 *
 * @version 1.01     2014-05-13
 * @author Christian Dühl
 */

public class FunctionViewMouseListener implements MouseListener {

    private final RangeSelectionReactor rangeSelectionListener;

    private Point coordsPressed;

    public FunctionViewMouseListener(RangeSelectionReactor rangeSelectionListener) {
        this.rangeSelectionListener = rangeSelectionListener;
    }

    @Override
    public void mouseClicked(MouseEvent event) {
    }

    /** Reagiert auf das Drücken einer Maustaste. */
    @Override
    public void mousePressed(MouseEvent event) {
        coordsPressed = event.getPoint();
        int x = coordsPressed.x;
        int y = coordsPressed.y;
        rangeSelectionListener.setRangeSelectionStartPoint(x, y);
    }

    /** Reagiert auf das Loslassen einer Maustaste. */
    @Override
    public void mouseReleased(MouseEvent event) {
        Point coordsReleased = event.getPoint();

        int xPixelMin = coordsPressed.x;
        int yPixelMin = coordsPressed.y;
        int xPixelMax = coordsReleased.x;
        int yPixelMax = coordsReleased.y;

        if (xPixelMin > xPixelMax) {
            int temp = xPixelMin;
            xPixelMin = xPixelMax;
            xPixelMax = temp;
        }

        if (yPixelMin > yPixelMax) {
            int temp = yPixelMin;
            yPixelMin = yPixelMax;
            yPixelMax = temp;
        }

        rangeSelectionListener.setRangeSelection(xPixelMin, yPixelMin,
                xPixelMax, yPixelMax);
    }

    @Override
    public void mouseEntered(MouseEvent event) {
    }

    @Override
    public void mouseExited(MouseEvent event) {
    }

}
