package de.duehl.math.functionviewer;

import static org.junit.Assert.*;

import org.junit.Test;

import de.congrace.exp4j.Calculable;
import de.congrace.exp4j.ExpressionBuilder;
import de.congrace.exp4j.UnknownFunctionException;
import de.congrace.exp4j.UnparsableExpressionException;

/**
 * Siehe:
 * http://www.objecthunter.net/tinybo/blog/articles/86
 * http://www.objecthunter.net/exp4j/index.html
 */

public class Exp4JTest {

    private final static double EPSILON = 0.000000001d;

    @Test
    public void test01() throws UnknownFunctionException,
            UnparsableExpressionException {
        Calculable calc = new ExpressionBuilder("x * y - 2")
                .withVariableNames("x", "y")
                .build();

        calc.setVariable("x", 1);
        calc.setVariable("y", 2);
        assertTrue(calc.calculate() == 0);
    }

    @Test
    public void test02() throws UnknownFunctionException,
            UnparsableExpressionException {
        Calculable calc = new ExpressionBuilder("x * y - 2")
                .withVariableNames("x", "y")
                .build();

        calc.setVariable("x", 1);
        calc.setVariable("y", 2);
        assertTrue(calc.calculate() == 0);

        calc.setVariable("x", 5);
        calc.setVariable("y", -2);
        assertTrue(calc.calculate() == -12);
    }

    @Test
    public void test03() throws UnknownFunctionException,
            UnparsableExpressionException {
        Calculable calc = new ExpressionBuilder("sin(x)")
                .withVariableNames("x")
                .build();

        calc.setVariable("x", 0);
        assertEquals(0d, calc.calculate(), EPSILON);

        calc.setVariable("x", Math.PI / 2);
        assertEquals(1d, calc.calculate(), EPSILON);

        calc.setVariable("x", Math.PI);
        assertEquals(0d, calc.calculate(), EPSILON);

        calc.setVariable("x", Math.PI * 3 / 2);
        assertEquals(-1d, calc.calculate(), EPSILON);

        calc.setVariable("x", 2 * Math.PI);
        assertEquals(0d, calc.calculate(), EPSILON);
    }

}
