package de.duehl.swing.ui.menu;

/*
 * Copyright 2016 Christian Dühl. All rights reserved.
 *
 * This program is free software. You can redistribute it and/or
 * modify it under the same terms as perl:
 *
 * general:  http://dev.perl.org/licenses/
 * GPL:      http://dev.perl.org/licenses/gpl1.html
 * artistic: http://dev.perl.org/licenses/artistic.html
 */

import java.awt.event.ActionListener;

import javax.swing.JCheckBoxMenuItem;
import javax.swing.KeyStroke;

/**
 * Diese Klasse stellt eine kleine Erweiterung des JMenuItems dar, um JMenuItems hübscher erzeugen
 * zu können.
 *
 * Verwendung mit:
 *
 *  return new MyMenuItem("Aus einem Verzeichnis laden ...")
 *          .mnemonic('l')
 *          .accelerator(KeyEvent.VK_L, Event.CTRL_MASK)
 *          .actionListener(new ActionListener() {
 *              @Override
 *              public void actionPerformed(ActionEvent e) {
 *                  logic.loadFromDisk();
 *              }
 *          });
 *
 * @version 1.01     2017-12-21
 * @author Christian Dühl
 */

public class MyCheckBoxMenuItem extends JCheckBoxMenuItem {

    private static final long serialVersionUID = 1L;

    public MyCheckBoxMenuItem(String text) {
        super(text);
    }

    public MyCheckBoxMenuItem mnemonic(char mnemonic) {
        setMnemonic(mnemonic);
        return this;
    }

    public MyCheckBoxMenuItem mnemonic(int mnemonic) {
        setMnemonic((char) mnemonic);
        return this;
    }

    public MyCheckBoxMenuItem accelerator(int keyCode, int modifiers) {
        setAccelerator(KeyStroke.getKeyStroke(keyCode, modifiers));
        return this;
    }

    public MyCheckBoxMenuItem actionListener(ActionListener actionListener) {
        addActionListener(actionListener);
        return this;
    }

}
